@@ -1,22 +1,14 @@
 /*
- * Copyright (C) 2004, 2005, 2007  Internet Systems Consortium, Inc. ("ISC")
- * Copyright (C) 1999-2003  Internet Software Consortium.
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: platform.h.in,v 1.34.18.9 2007/09/13 05:04:01 each Exp $ */
-
 #ifndef ISC_PLATFORM_H
 #define ISC_PLATFORM_H 1
 
@@ -26,11 +18,6 @@
  ***** Platform-dependent defines.
  *****/
 
-/*
- * Define if the platform has <strings.h>.
- */
-#define ISC_PLATFORM_HAVESTRINGSH 1
-
 /***
  *** Network.
  ***/
@@ -98,88 +85,11 @@
  */
 #undef ISC_PLATFORM_NEEDPTON
 
-/*! \brief
- * If this system needs inet_aton(), ISC_PLATFORM_NEEDATON will be defined.
- */
-#undef ISC_PLATFORM_NEEDATON
-
 /*! \brief
  * If this system needs in_port_t, ISC_PLATFORM_NEEDPORTT will be defined.
  */
 #undef ISC_PLATFORM_NEEDPORTT
 
-/*! \brief
- * If the system needs strsep(), ISC_PLATFORM_NEEDSTRSEP will be defined.
- */
-#undef ISC_PLATFORM_NEEDSTRSEP
-
-/*! \brief
- * If the system needs strlcpy(), ISC_PLATFORM_NEEDSTRLCPY will be defined.
- */
-#define ISC_PLATFORM_NEEDSTRLCPY 1
-
-/*! \brief
- * If the system needs strlcat(), ISC_PLATFORM_NEEDSTRLCAT will be defined.
- */
-#define ISC_PLATFORM_NEEDSTRLCAT 1
-
-/*! \brief
- * Define either ISC_PLATFORM_BSD44MSGHDR or ISC_PLATFORM_BSD43MSGHDR.
- */
-#define ISC_NET_BSD44MSGHDR 1
-
-/*! \brief
- * Define if PTHREAD_ONCE_INIT should be surrounded by braces to
- * prevent compiler warnings (such as with gcc on Solaris 2.8).
- */
-#undef ISC_PLATFORM_BRACEPTHREADONCEINIT
-
-/*! \brief
- * Define on some UnixWare systems to fix erroneous definitions of various
- * IN6_IS_ADDR_* macros.
- */
-#undef ISC_PLATFORM_FIXIN6ISADDR
-
-/*
- *** Printing.
- ***/
-
-/*! \brief
- * If this system needs vsnprintf() and snprintf(), ISC_PLATFORM_NEEDVSNPRINTF
- * will be defined.
- */
-#undef ISC_PLATFORM_NEEDVSNPRINTF
-
-/*! \brief
- * If this system need a modern sprintf() that returns (int) not (char*).
- */
-#undef ISC_PLATFORM_NEEDSPRINTF
-
-/*! \brief
- * The printf format string modifier to use with isc_uint64_t values.
- */
-#define ISC_PLATFORM_QUADFORMAT "ll"
-
-/*! \brief
- * Defined if we are using threads.
- */
-#define ISC_PLATFORM_USETHREADS 1
-
-/*! \brief
- * Defined if unistd.h does not cause fd_set to be delared.
- */
-#undef ISC_PLATFORM_NEEDSYSSELECTH
-
-/*! \brief
- * Type used for resource limits.
- */
-#define ISC_PLATFORM_RLIMITTYPE rlim_t
-
-/*! \brief
- * Define if your compiler supports "long long int".
- */
-#define ISC_PLATFORM_HAVELONGLONG 1
-
 /*! \brief
  * Define if the system has struct lifconf which is a extended struct ifconf
  * for IPv6.
@@ -198,9 +108,9 @@
 #undef ISC_PLATFORM_HAVEIF_LADDRREQ
 
 /*! \brief
- * Used to control how extern data is linked; needed for Win32 platforms.
+ * Define either ISC_PLATFORM_BSD44MSGHDR or ISC_PLATFORM_BSD43MSGHDR.
  */
-#undef ISC_PLATFORM_USEDECLSPEC
+#define ISC_NET_BSD44MSGHDR 1
 
 /*! \brief
  * Define if the system supports if_nametoindex.
@@ -208,15 +118,157 @@
 #define ISC_PLATFORM_HAVEIFNAMETOINDEX 1
 
 /*! \brief
+ * Define on some UnixWare systems to fix erroneous definitions of various
+ * IN6_IS_ADDR_* macros.
+ */
+#undef ISC_PLATFORM_FIXIN6ISADDR
+
+/*! \brief
+ * Define if the system has struct sockaddr_storage.
+ */
+#define ISC_PLATFORM_HAVESOCKADDRSTORAGE 1
+
+/*! \brief
+ * Define if the system has TCP_FASTOPEN socket option.
+ */
+#undef ISC_PLATFORM_HAVETFO
+
+/*! \brief
+ * Define if the system supports kqueue multiplexing
+ */
+#undef ISC_PLATFORM_HAVEKQUEUE
+
+/*! \brief
+ * Define if the system supports epoll multiplexing
+ */
+#define ISC_PLATFORM_HAVEEPOLL 1
+
+/*! \brief
+ * Define if the system supports /dev/poll multiplexing
+ */
+#undef ISC_PLATFORM_HAVEDEVPOLL
+
+/*! \brief
+ * Define if we want to log backtrace
+ */
+#define ISC_PLATFORM_USEBACKTRACE 1
+
+/*
+ *** Printing.
+ ***/
+
+/*! \brief
+ * If this system needs vsnprintf() and snprintf(), ISC_PLATFORM_NEEDVSNPRINTF
+ * will be defined.
+ */
+#undef ISC_PLATFORM_NEEDVSNPRINTF
+
+/*! \brief
+ * If this system need a modern sprintf() that returns (int) not (char*).
+ */
+#undef ISC_PLATFORM_NEEDSPRINTF
+
+/*! \brief
+ * If this system need a modern printf() that format size %z (size_t).
+ */
+#undef ISC_PLATFORM_NEEDPRINTF
+
+/*! \brief
+ * If this system need a modern fprintf() that format size %z (size_t).
+ */
+#undef ISC_PLATFORM_NEEDFPRINTF
+
+/***
+ *** String functions.
+ ***/
+/*
+ * If the system needs strsep(), ISC_PLATFORM_NEEDSTRSEP will be defined.
+ */
+#undef ISC_PLATFORM_NEEDSTRSEP
+
+/*
+ * If the system needs strlcpy(), ISC_PLATFORM_NEEDSTRLCPY will be defined.
+ */
+#define ISC_PLATFORM_NEEDSTRLCPY 1
+
+/*
+ * If the system needs strlcat(), ISC_PLATFORM_NEEDSTRLCAT will be defined.
+ */
+#define ISC_PLATFORM_NEEDSTRLCAT 1
+
+/*
  * Define if this system needs strtoul.
  */
 #undef ISC_PLATFORM_NEEDSTRTOUL
 
-/*! \brief
+/*
  * Define if this system needs memmove.
  */
 #undef ISC_PLATFORM_NEEDMEMMOVE
 
+/*
+ * Define if this system needs strcasestr.
+ */
+#undef ISC_PLATFORM_NEEDSTRCASESTR
+
+/***
+ *** Miscellaneous.
+ ***/
+
+/*
+ * Defined if we are using threads.
+ */
+#define ISC_PLATFORM_USETHREADS 1
+
+/*
+ * Defined if unistd.h does not cause fd_set to be delared.
+ */
+#undef ISC_PLATFORM_NEEDSYSSELECTH
+
+/*
+ * Defined to <gssapi.h> or <gssapi/gssapi.h> for how to include
+ * the GSSAPI header.
+ */
+
+
+/*
+ * Defined to <gssapi_krb5.h> or <gssapi/gssapi_krb5.h> for how to
+ * include the GSSAPI KRB5 header.
+ */
+
+
+/*
+ * Defined to <krb5.h> or <krb5/krb5.h> for how to include
+ * the KRB5 header.
+ */
+
+
+/*
+ * Define if the system has nanosecond-level accuracy in file stats.
+ */
+#define ISC_PLATFORM_HAVESTATNSEC 1
+
+/*
+ * Type used for resource limits.
+ */
+#define ISC_PLATFORM_RLIMITTYPE rlim_t
+
+/*
+ * Define if your compiler supports "long long int".
+ */
+#define ISC_PLATFORM_HAVELONGLONG 1
+
+/*
+ * Define if PTHREAD_ONCE_INIT should be surrounded by braces to
+ * prevent compiler warnings (such as with gcc on Solaris 2.8).
+ */
+#undef ISC_PLATFORM_BRACEPTHREADONCEINIT
+
+/*
+ * Used to control how extern data is linked; needed for Win32 platforms.
+ */
+#undef ISC_PLATFORM_USEDECLSPEC
+
 /*
  * Define if the platform has <sys/un.h>.
  */
@@ -224,22 +276,40 @@
 
 /*
  * If the "xadd" operation is available on this architecture,
- * ISC_PLATFORM_HAVEXADD will be defined. 
+ * ISC_PLATFORM_HAVEXADD will be defined.
  */
 #define ISC_PLATFORM_HAVEXADD 1
 
 /*
- * If the "atomic swap" operation is available on this architecture,
- * ISC_PLATFORM_HAVEATOMICSTORE" will be defined. 
+ * If the "xaddq" operation (64bit xadd) is available on this architecture,
+ * ISC_PLATFORM_HAVEXADDQ will be defined.
+ */
+#undef ISC_PLATFORM_HAVEXADDQ
+
+/*
+ * If the 32-bit "atomic swap" operation is available on this
+ * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
  */
 #define ISC_PLATFORM_HAVEATOMICSTORE 1
 
+/*
+ * If the 64-bit "atomic swap" operation is available on this
+ * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
+ */
+#undef ISC_PLATFORM_HAVEATOMICSTOREQ
+
 /*
  * If the "compare-and-exchange" operation is available on this architecture,
- * ISC_PLATFORM_HAVECMPXCHG will be defined. 
+ * ISC_PLATFORM_HAVECMPXCHG will be defined.
  */
 #define ISC_PLATFORM_HAVECMPXCHG 1
 
+/*
+ * If <stdatomic.h> is available on this architecture,
+ * ISC_PLATFORM_HAVESTDATOMIC will be defined.
+ */
+#undef ISC_PLATFORM_HAVESTDATOMIC
+
 /*
  * Define if gcc ASM extension is available
  */
@@ -253,13 +323,43 @@
 /*
  * Define if the standard __asm function must be used.
  */
+#undef ISC_PLATFORM_USESTDASM
 
+/*
+ * Define with the busy wait nop asm or function call.
+ */
+#define ISC_PLATFORM_BUSYWAITNOP asm("rep; nop")
+
+/*
+ * Define if the platform has <strings.h>.
+ */
+#define ISC_PLATFORM_HAVESTRINGSH 1
+
+/*
+ * Define if the hash functions must be provided by OpenSSL.
+ */
+#undef ISC_PLATFORM_OPENSSLHASH
+
+/*
+ * Define if AES support is wanted
+ */
+#define ISC_PLATFORM_WANTAES 1
+
+/*
+ * Defines for the noreturn attribute.
+ */
+#define ISC_PLATFORM_NORETURN_PRE
+#define ISC_PLATFORM_NORETURN_POST __attribute__((noreturn))
+
+/***
+ ***	Windows dll support.
+ ***/
 
 /*
  * Define if MacOS style of PPC assembly must be used.
  * e.g. "r6", not "6", for register six.
  */
-
+#undef ISC_PLATFORM_USEMACASM
 
 #ifndef ISC_PLATFORM_USEDECLSPEC
 #define LIBISC_EXTERNAL_DATA
@@ -267,6 +367,7 @@
 #define LIBISCCC_EXTERNAL_DATA
 #define LIBISCCFG_EXTERNAL_DATA
 #define LIBBIND9_EXTERNAL_DATA
+#define LIBTESTS_EXTERNAL_DATA
 #else /*! \brief ISC_PLATFORM_USEDECLSPEC */
 #ifdef LIBISC_EXPORTS
 #define LIBISC_EXTERNAL_DATA __declspec(dllexport)
@@ -293,6 +394,11 @@
 #else
 #define LIBBIND9_EXTERNAL_DATA __declspec(dllimport)
 #endif
+#ifdef LIBTESTS_EXPORTS
+#define LIBTESTS_EXTERNAL_DATA __declspec(dllexport)
+#else
+#define LIBTESTS_EXTERNAL_DATA __declspec(dllimport)
+#endif
 #endif /*! \brief ISC_PLATFORM_USEDECLSPEC */
 
 /*
